@@ -1,8 +1,5 @@
 from neo.Core.TX.Transaction import Transaction, TransactionType
-import sys
 from neocore.Cryptography.ECCurve import ECDSA
-from neo.Settings import settings
-from neocore.Fixed8 import Fixed8
 
 
 class EnrollmentTransaction(Transaction):
@@ -29,15 +26,6 @@ class EnrollmentTransaction(Transaction):
         """
         return super(EnrollmentTransaction, self).Size() + self.PublicKey.Size()
 
-    def SystemFee(self):
-        """
-        Get the enrollment fee.
-
-        Returns:
-            Fixed8:
-        """
-        return Fixed8(int(settings.ENROLLMENT_TX_FEE))
-
     def DeserializeExclusiveData(self, reader):
         """
         Deserialize full object.
