@@ -1,6 +1,6 @@
 import binascii
 from logzero import logger
-from neo.SmartContract.StorageIterator import StorageIterator
+from neo.SmartContract.Iterable import EnumeratorBase
 
 
 class DBCollection:
@@ -94,8 +94,24 @@ class DBCollection:
 
         return item
 
+    def ReplaceOrAdd(self, keyval, new_instance):
+
+        item = new_instance
+
+        if keyval in self.Deleted:
+            self.Deleted.remove(keyval)
+
+        self.Add(keyval, item)
+
+        return item
+
     def GetOrAdd(self, keyval, new_instance):
 
+        existing = self.TryGet(keyval)
+
+        if existing:
+            return existing
+
         item = new_instance
 
         if keyval in self.Deleted:
@@ -175,7 +191,7 @@ class DBCollection:
         # then take the dict and make a list of tuples
         final_collection = [(k, v) for k, v in {**db_results, **candidates}.items()]
 
-        return StorageIterator(iter(final_collection))
+        return EnumeratorBase(iter(final_collection))
 
     def Find(self, key_prefix):
         key_prefix = self.Prefix + key_prefix
