@@ -1,12 +1,12 @@
 import logging
-from peewee import *
+from peewee import Proxy, SqliteDatabase
 from logzero import logger
 
 logger = logging.getLogger('peewee')
 logger.setLevel(logging.ERROR)
 
 
-class PWDatabase(object):
+class PWDatabase:
 
     __proxy = None
 
