@@ -31,6 +31,7 @@ from neo.VM.ScriptBuilder import ScriptBuilder
 from neo.VM.VMState import VMStateStr
 from neo.Implementations.Wallets.peewee.Models import Account
 from neo.Prompt.Utils import get_asset_id
+from neo.Wallets.Wallet import Wallet
 
 
 class JsonRpcError(Exception):
@@ -79,19 +80,9 @@ class JsonRpcApi:
         self.port = port
         self.wallet = wallet
 
-    #
-    # JSON-RPC API Route
-    #
-    @app.route('/')
-    @json_response
-    @cors_header
-    def home(self, request):
-        # {"jsonrpc": "2.0", "id": 5, "method": "getblockcount", "params": []}
-        body = None
-        request_id = None
+    def get_data(self, body: dict):
 
         try:
-            body = json.loads(request.content.read().decode("utf-8"))
             request_id = body["id"] if body and "id" in body else None
 
             if "jsonrpc" not in body or body["jsonrpc"] != "2.0":
@@ -111,10 +102,6 @@ class JsonRpcApi:
                 "result": result
             }
 
-        except JSONDecodeError as e:
-            error = JsonRpcError.parseError()
-            return self.get_custom_error_payload(request_id, error.code, error.message)
-
         except JsonRpcError as e:
             return self.get_custom_error_payload(request_id, e.code, e.message)
 
@@ -122,6 +109,35 @@ class JsonRpcApi:
             error = JsonRpcError.internalError(str(e))
             return self.get_custom_error_payload(request_id, error.code, error.message)
 
+    #
+    # JSON-RPC API Route
+    #
+    @app.route('/')
+    @json_response
+    @cors_header
+    def home(self, request):
+        # {"jsonrpc": "2.0", "id": 5, "method": "getblockcount", "params": []}
+        # or multiple requests in 1 transaction
+        # [{"jsonrpc": "2.0", "id": 1, "method": "getblock", "params": [10], {"jsonrpc": "2.0", "id": 2, "method": "getblock", "params": [10,1]}
+        request_id = None
+
+        try:
+            content = json.loads(request.content.read().decode("utf-8"))
+
+            # test if it's a multi-request message
+            if isinstance(content, list):
+                result = []
+                for body in content:
+                    result.append(self.get_data(body))
+                return result
+
+            # otherwise it's a single request
+            return self.get_data(content)
+
+        except JSONDecodeError as e:
+            error = JsonRpcError.parseError()
+            return self.get_custom_error_payload(request_id, error.code, error.message)
+
     def json_rpc_method_handler(self, method, params):
 
         if method == "getaccountstate":
@@ -238,9 +254,6 @@ class JsonRpcApi:
             result = NodeLeader.Instance().Relay(transaction)
             return result
 
-        elif method == "submitblock":
-            raise NotImplementedError()
-
         elif method == "validateaddress":
             return self.validateaddress(params)
 
@@ -253,6 +266,12 @@ class JsonRpcApi:
             else:
                 raise JsonRpcError(-400, "Access denied.")
 
+        elif method == "getwalletheight":
+            if self.wallet:
+                return self.wallet.WalletHeight
+            else:
+                raise JsonRpcError(-400, "Access denied.")
+
         elif method == "listaddress":
             if self.wallet:
                 return self.list_address()
